@@ -48,6 +48,8 @@ struct _YelpSettingsPriv {
     gboolean      show_text_cursor;
 
     gboolean      editor_mode;
+
+    GHashTable   *bookmarks;
 };
 
 enum {
@@ -171,7 +173,7 @@ yelp_settings_class_init (YelpSettingsClass *klass)
                                      PROP_SHOW_TEXT_CURSOR,
                                      g_param_spec_boolean ("show-text-cursor",
                                                            _("Show Text Cursor"),
-                                                           _("Show the text cursor or caret for accessibile navigation"),
+                                                           _("Show the text cursor or caret for accessible navigation"),
                                                            FALSE,
                                                            G_PARAM_READWRITE | G_PARAM_STATIC_NAME |
                                                            G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
@@ -227,6 +229,9 @@ yelp_settings_init (YelpSettings *settings)
 	settings->priv->setfonts[i] = NULL;
 	settings->priv->fonts[i] = NULL;
     }
+
+    settings->priv->bookmarks = g_hash_table_new_full (g_str_hash, g_str_equal,
+                                                       g_free, NULL);
 }
 
 static void
@@ -859,11 +864,11 @@ gtk_theme_changed (GtkSettings  *gtk_settings,
                 settings->priv->colors[YELP_SETTINGS_COLOR_RED_BORDER]);
 
     /* YELP_SETTINGS_COLOR_YELLOW */
-    hsv_to_hex (54,
-                0.2,
+    hsv_to_hex (60,
+                0.25,
                 base_v - ((base_v - text_v) * 0.01),
                 settings->priv->colors[YELP_SETTINGS_COLOR_YELLOW_BASE]);
-    hsv_to_hex (54,
+    hsv_to_hex (60,
                 1.0,
                 base_v - ((base_v - text_v) * 0.07),
                 settings->priv->colors[YELP_SETTINGS_COLOR_YELLOW_BORDER]);
